@@ -65,12 +65,13 @@ class KeycloakEnvironment():
                          validate_certs=self.validate_certs)
             keycloak_client = kc.get_client_by_clientid(client_id=client, realm=realm)
             keycloak_auth_client_secret = kc.get_client_secret_by_id(keycloak_client["id"], realm=realm)
+            keycloak_auth_client_secret_value = keycloak_auth_client_secret['value'] if keycloak_auth_client_secret is not None and 'value' in keycloak_auth_client_secret else None
             
             headers = get_service_account_token(
                 base_url=self.keycloak_url,
                 auth_realm=self.keycloak_auth_realm,
                 client_id=client,
-                client_secret=keycloak_auth_client_secret["value"],
+                client_secret=keycloak_auth_client_secret_value,
                 validate_certs=self.validate_certs)
         self.headers = headers
         return headers
@@ -78,6 +79,17 @@ class KeycloakEnvironment():
     def authenticateByUsernamePassword(self):
         headers = {}
         if self.keycloak_enabled:
+            kc = KeycloakAPI(auth_keycloak_url=self.keycloak_url,
+                         auth_client_id="admin-cli",
+                         auth_username=self.keycloak_admin_auth_user,
+                         auth_password=self.keycloak_admin_auth_password,
+                         auth_realm=self.keycloak_admin_auth_realm,
+                         auth_client_secret=None,
+                         validate_certs=self.validate_certs)
+            keycloak_client = kc.get_client_by_clientid(client_id=self.keycloak_auth_client_id, realm=self.keycloak_auth_realm)
+            keycloak_auth_client_secret = kc.get_client_secret_by_id(keycloak_client["id"], realm=self.keycloak_auth_realm)
+            keycloak_auth_client_secret_value = keycloak_auth_client_secret['value'] if keycloak_auth_client_secret is not None and 'value' in keycloak_auth_client_secret else None
+
             headers = get_token(
                 base_url=self.keycloak_url,
                 validate_certs=self.validate_certs,
@@ -85,6 +97,6 @@ class KeycloakEnvironment():
                 client_id=self.keycloak_auth_client_id,
                 auth_username=self.keycloak_auth_user,
                 auth_password=self.keycloak_auth_password,
-                client_secret=self.keycloak_auth_client_secret)
+                client_secret=keycloak_auth_client_secret_value)
         self.headers = headers
         return headers
